From 6369d7c83237fc26d2374a86c18d9dac7abe255a Mon Sep 17 00:00:00 2001
From: Richard Uhler <ruhler@google.com>
Date: Fri, 4 Dec 2020 17:12:14 -0800
Subject: [PATCH] Change "graph-level" to "global" in docs for consistency.

The documentation for tf.random.set_seed sometimes uses "global" and sometimes
uses "graph-level" to refer to the global seed. Update the documentation for
that method to consistency refer to it as the global seed.

PiperOrigin-RevId: 345787276
Change-Id: Ia6157c526b19e68d9e19f2f1af62022ce1f92649
---
 tensorflow/python/framework/random_seed.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/tensorflow/python/framework/random_seed.py b/tensorflow/python/framework/random_seed.py
index 28d1720428b..f21c5cdb591 100644
--- a/tensorflow/python/framework/random_seed.py
+++ b/tensorflow/python/framework/random_seed.py
@@ -206,12 +206,12 @@ def set_seed(seed):
 
     1. If neither the global seed nor the operation seed is set: A randomly
       picked seed is used for this op.
-    2. If the graph-level seed is set, but the operation seed is not:
+    2. If the global seed is set, but the operation seed is not:
       The system deterministically picks an operation seed in conjunction with
       the graph-level seed so that it gets a unique random sequence. Within the
       same version of tensorflow and user code, this sequence is deterministic.
       However across different versions, this sequence might change. If the
       code depends on particular seeds to work, specify both graph-level
       and operation-level seeds explicitly.
     3. If the operation seed is set, but the global seed is not set:
       A default global seed and the specified operation seed are used to
@@ -206,12 +206,12 @@ def set_seed(seed):
       The system deterministically picks an operation seed in conjunction with
-      the graph-level seed so that it gets a unique random sequence. Within the
+      the global seed so that it gets a unique random sequence. Within the
       same version of tensorflow and user code, this sequence is deterministic.
       However across different versions, this sequence might change. If the
@@ -206,12 +206,12 @@ def set_seed(seed):
       same version of tensorflow and user code, this sequence is deterministic.
       However across different versions, this sequence might change. If the
-      code depends on particular seeds to work, specify both graph-level
+      code depends on particular seeds to work, specify both global
       and operation-level seeds explicitly.
     3. If the operation seed is set, but the global seed is not set: